@@ -5,7 +5,7 @@ from PIL import Image
 
 from ..layeredimage import LayeredImage
 from ..layergroup import Layer
-from .common import getRasterLayers
+from .common import expandLayersToCanvas
 
 # pylint: disable=invalid-name
 
@@ -19,14 +19,17 @@ def openLayer_GIF(file: str) -> LayeredImage:
 	for index in range(project.n_frames):
 		project.seek(index)
 		layers.append(
-		Layer("Frame {} ({}ms)".format(len(layers) + 1, project.info["duration"]),
-		project.copy(),
-		projectSize))
+			Layer(
+				"Frame {} ({}ms)".format(len(layers) + 1, project.info["duration"]),
+				project.copy(),
+				projectSize,
+			)
+		)
 	project.close()
 	return LayeredImage(layers, projectSize)
 
 
 def saveLayer_GIF(fileName: str, layeredImage: LayeredImage) -> None:
 	"""Save a layered image as .gif."""
-	layers = getRasterLayers(layeredImage, "GIF")
+	layers = expandLayersToCanvas(layeredImage, "GIF")
 	layers[0].save(fileName, duration=100, save_all=True, append_images=layers[1:])
